;===========================================================================
;                          Alpha's Command File
;===========================================================================

; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;



;-| Supers Motions |------------------------------------------------


[Command]
name = "hyper1"
command = ~F, B, D, DF, F, x+y
time = 38
[Command]
name = "hyper1"
command = ~F, B, D, DF, F, y+z
time = 38
[Command]
name = "hyper1"
command = ~F, B, D, DF, F, x+z
time = 38





[Command]
name = "tierra"
command = ~D, DF, F, x+y
time = 38
[Command]
name = "tierra"
command = ~D, DF, F, y+z
time = 38
[Command]
name = "tierra"
command = ~D, DF, F, x+z
time = 38
[Command]
name = "mar"
command = ~D, DB, B, x+y
time = 38
[Command]
name = "mar"
command = ~D, DB, B, y+z
time = 38
[Command]
name = "mar"
command = ~D, DB, B, x+z
time = 38
[Command]
name = "aire"
command = ~B, F, x+y
time = 38
[Command]
name = "aire"
command = ~B, F, y+z
time = 38
[Command]
name = "aire"
command = ~B, F, x+z
time = 38








[Command]
name = "hyper2"
command = F, B, x+z; B, D, F, z+c
time = 350


[Command]
name = "hyper2"
command = ~D, DB, B, y+a
time = 38
[Command]
name = "hyper2"
command = ~D, DB, B, a+b
time = 38
[Command]
name = "hyper2"
command = ~D, DB, B, x+a
time = 38
[Command]
name = "hyper2"
command = ~D, DB, B, y+b
time = 38
[Command]
name = "hyper2"
command = ~D, DB, B, x+b
time = 38

[Command]
name = "hyper2"
command = ~a, F, B, x, c
time = 38



;[Command]
;name = "hyper6"
;command = $D, F, D, B, x+y
;time = 100
;[Command]
;name = "hyper6"
;command = $D, F, D, B, x+z
;time = 100
;[Command]
;name = "hyper6"
;command = $D, F, D, B, z+y
;time = 100

[Command]
name = "hyper6"
command = x, y, $B, $F, a, b, z
time = 100


[Command]
name = "shoryukenx"
command = ~F, D, DF, x
[Command]
name = "shoryukeny"
command = ~F, D, DF, y
[Command]
name = "shoryukena"
command = ~F, D, DF, s
[Command]
name = "shoryukenb"
command = ~F, D, DF, z

[Command]
name = "hadokenx"
command = ~D, DF, F, x
[Command]
name = "hadokeny"
command = ~D, DF, F, s
[Command]
name = "hadokena"
command = ~D, DF, F, y
[Command]
name = "hadokenb"
command = ~D, DF, F, z

[Command]
name = "DashHit"
command = ~D, DF, F, z
time = 10





[Command]
name = "slashcutx"
command = ~B, D, DB, x
[Command]
name = "slashcuty"
command = ~B, D, DB, y
[Command]
name = "slashcuta"
command = ~B, D, DB, z
[Command]
name = "slashcutb"
command = ~B, D, DB, s


[Command]
name = "cresentx"
command = ~B, D, DB, a
[Command]
name = "cresenty"
command = ~B, D, DB, b
[Command]
name = "cresenta"
command = ~B, D, DB, c
[Command]
name = "cresentb"
command = ~B, D, DB, s


[Command]
name = "slashx"
command = ~D, DB, B, c
[Command]
name = "slashy"
command = ~D, DB, B, s
[Command]
name = "slasha"
command = ~D, DB, B, a
[Command]
name = "slashb"
command = ~D, DB, B, b

[Command]
name = "UpperX"
command = ~B, F, x
time = 10

[Command]
name = "SlasherX"
command = ~F, B, x
time = 10

[Command]
name = "ShoryuenzanX"
command = ~D, U, x
time = 10

[Command]
name = "MoonslashX"
command = ~U, D, x
time = 10


[Command]
name = "slash2"
command = ~B, D, F, x
time = 10
[Command]
name = "slash2"
command = ~B, D, F, y
time = 10
[Command]
name = "slash2"
command = ~B, D, F, a
time = 10
[Command]
name = "slash2"
command = ~B, D, F, b
time = 10

;----- |Botones simples| -----

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Button |-----------------------------------------------------------

[Command]
name = "ar"
command = /U
time = 1
[Command]
name = "at"
command = /UB
time = 1
[Command]
name = "ad"
command = /UF
time = 1
[Command]
name = "ab"
command = /D
time = 1
[Command]
name = "aa"
command = /DB
time = 1
[Command]
name = "ae"
command = /DF
time = 1

[Command]
name = "parry"
command = ~$B,$F
time = 5

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1



[Command]
name = "sjump"
command = ~$D, U
time = 5

[Command]
name = "sjumpf"
command = ~$D, UF
time = 5

[Command]
name = "sjumpb"
command = ~$D, UB
time = 5

[Command]
name = "wjumpb"
command = ~$B, $F
time = 5
[Command]
name = "wjumpf"
command = ~$B, $F
time = 5


[Command]
name = "recovery"
command = ~D, U
time = 10



[Command]
name = "12a"
command = /x
time = 1
[Command]
name = "12b"
command = /y
time = 1

[Command]
name = "cz1"
command = /c
time = 1
[Command]
name = "cz2"
command = /z
time = 1


[Command]
name = "cz"
command = z+c
time = 7

[Command]
name = "by"
command =b+y
time = 7
[Command]
name = "ax"
command = a+x
time = 7



[Command]
name = "parry"
command = ~$F
time = 5

[Command]
name = "stop"
command = ~D, DF, F, c+z
time= 12


;----- |Doble| -----

[Command]
name = "FF"     ;Requerido (no quitar)
command = F, F
time = 10

[Command]
name = "BB"     ;Requerido (no quitar)
command = B, B
time = 10


;----- |Dir...| -----

[Command]
name = "holdfwd";Requerido (no quitar)
command = /$F
time = 1

[Command]
name = "holdback";Requerido (no quitar)
command = /$B
time = 1

[Command]
name = "holdup" ;Requerido (no quitar)
command = /$U
time = 1

[Command]
name = "holddown";Requerido (no quitar)
command = /$D
time = 1

[Statedef -1]

;===========================================================================
;                           Hyper combos
;===========================================================================



;------ Shinku Ha Do Ken ------
[State -1]
type = ChangeState
value = 3000
triggerall = !var(10)
triggerall = command = "hyper1"
triggerall = power >= 1000
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = [200,450]
trigger2 = time > 11

;------ Shinku Ha Do Ken aereo------
[State -1]
type = ChangeState
value = 3050
triggerall = !var(10)
triggerall = command = "hyper1"
triggerall = power >= 1000
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = [600,650]
trigger2 = time > 11


;------ Corte de aire ------
[State -1]
type = null;ChangeState
value = 470
triggerall = command = "aire"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,450]
trigger2 = stateno != 430
trigger2 = time > 11
trigger3 = stateno = [3301,3310]
trigger4 = stateno = 430
trigger4 = time > 19

;------ Corte de tierra ------
[State -1]
type = null;ChangeState
value = 3310
triggerall = command = "mar"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,450]
trigger2 = time > 11
trigger3 = stateno = 3301
trigger4 = stateno = 3


;------ Corte de tierra ------
[State -1]
type = null;ssChangeState
value = 3300
triggerall = command = "tierra"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,450]
trigger2 = time > 11


;------ Raging demon ------
[State -1]
type = ChangeState
value = 3100
triggerall = command = "hyper6"
triggerall = power >= 1000 
trigger1 = ctrl
trigger2 = stateno = [200,777]
trigger3 = stateno = [150,155]
trigger3 = stateno = [0,120]

[State -1]
type = ChangeState
value = 3100
triggerall = var(10)
triggerall = command = "hyper6"
triggerall = power >= 1000 
trigger1 = ctrl
trigger2 = stateno = [100,777]
trigger3 = stateno = [150,155]

;------ Dark Hold ------
[State -1]
type = ChangeState
value = 3200
triggerall = command = "hyper2"
;triggerall = power >= 1000
triggerall = !Var(1)
triggerall = !var(3)
triggerall = p2bodydist X < 50
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,900]
trigger3 = stateno = [150,153]
trigger4 = stateno = 1300
trigger4 = movecontact

[State -1]
type = null;ChangeState
value = 3201
triggerall = command = "hyper2"
triggerall = var(3) = 1
trigger1 = statetype = S
trigger1 = ctrl = 1





;------ Shinku Ha Do Ken ------
[State -1]
type = ChangeState
value = 3000
triggerall = var(10)
triggerall = command = "z"
triggerall = power >= 1000
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = [200,777]
trigger2 = time > 11
;------ Shinku Ha Do Ken aereo------
[State -1]
type = ChangeState
value = 3050
triggerall = var(10)
triggerall = command = "z"
triggerall = power >= 1000
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = [200,777]
trigger2 = time > 11

;===========================================================================
;                           Especiales
;===========================================================================

;- | parry | ----------------------------------------------------------------
[State -1]
type = ChangeState
value = 1020
triggerall = Alive
triggerall = statetype != A
trigger1 = command = "parry"
trigger1 = stateno = [150,153] 

[State -1]
type = ChangeState
value = 1022
triggerall = Alive
triggerall = statetype = A
trigger1 = command = "parry"
trigger1 = stateno = [154,155]
trigger1 = Pos Y < -50



;------ Shoryu Cut ------
[State -1]
type = ChangeState
value = 1000
triggerall = !var(10)
triggerall = command = "shoryukenx" || command = "shoryukeny" || command = "shoryukenb" 
triggerall = statetype != A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = time > 6
trigger2 = stateno = [200,650]
trigger3 = stateno = 196
trigger4 = stateno = 1100
trigger4 = time > 30
trigger5 = movecontact = 1
trigger5 = stateno = [1050,1052]
trigger6 = stateno = [150,153]
trigger7 = stateno = [1201,1202]
trigger7 = MoveContact
trigger8 = stateno = 100
trigger9 = stateno = 701



;------ slash cut ------
[State -1]
type = ChangeState
value = 1300
triggerall = !var(10)
triggerall = command = "slashcutx" || command = "slashcuty" || command = "slashcuta" 
triggerall = statetype != A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = stateno = [200,900]
trigger3 = stateno = [150,153]
trigger3 = power >= 500
trigger4 = (stateno = 701) || (stateno = 1201)
trigger4 = time >= 10
trigger4 = P2Movetype = H

;------ cresent cut ------
[State -1]
type = ChangeState
value = 1200
triggerall = !var(10)
triggerall = command = "cresentx" || command = "cresenty" || command = "cresenta" 
trigger1 = ctrl
trigger2 = movecontact
trigger2 = stateno = [200,650]
trigger3 = stateno = 196
trigger4 = stateno = 1100
trigger4 = time > 30
trigger5 = stateno = [150,153]
trigger6 = stateno = 1002
trigger6 = pos Y < -100
trigger6 = time > 7
trigger7 = stateno = [1050,1052]


;----- slash Cut x1------
[State -1]
type = null;ChangeState
value = 1050
triggerall = !var(10)
triggerall = command = "slashx" || command = "slasha" || command = "slashb" 
triggerall = statetype != A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = stateno = [200,650]
trigger3 = stateno = 196
trigger4 = stateno = 1100
trigger4 = time > 30
trigger5 = stateno = [150,153]

;------ Ha Do Ken ------
[State -1]
type = ChangeState
value = 1100
triggerall = !var(10)
triggerall = command = "hadokenx" || command = "hadokena" || command = "hadokenb"
triggerall = statetype = S
trigger1 = ctrl
;trigger2 = movecontact
;trigger2 = stateno = [200,650]
;trigger3 = stateno = [150,153]

;------ Ha Do Ken (aereo) ------
[State -1]
type = ChangeState
value = 1150
triggerall = !var(10)
triggerall = command = "hadokenx" || command = "hadokena" || command = "hadokenb"
triggerall = statetype = A
trigger1 = ctrl
;trigger2 = movecontact
;trigger2 = stateno = [200,650]
;trigger3 = stateno = [154,155]



;------ Guard Push --------
[State -1];agachado
type = ChangeState
value = 1900
triggerall = !var(10)
triggerall = command = "ax"
triggerall = statetype = C
trigger1 = stateno = [150,153]

[State -1];parado
type = ChangeState
value = 1901
triggerall = !var(10)
triggerall = command = "ax"
triggerall = statetype = S
trigger1 = stateno = [150,153]

[State -1];saltando
type = ChangeState
value = 1902
triggerall = !var(10)
triggerall = command = "ax"
triggerall = statetype = A
trigger1 = stateno = [154,155]





[State -1, parry a]
type = null;ChangeState
value = 400
trigger1 = statetype = C
trigger1 = stateno = [150,153] 
trigger1 = command = "parry"
[State -1, parry p]
type = null;ChangeState
value = 200
trigger1 = statetype = S
trigger1 = stateno = [150,153] 
trigger1 = command = "parry"
[State -1, parry a]
type = null;ChangeState
value = 600
triggerall = statetype = A
trigger1 = stateno = [154,155]
trigger1 = command = "parry"



;Combo Braker
[State -1, cb]
type = ChangeState
value = 431
triggerall = var(10)
trigger1 = statetype != A
trigger1 = stateno = [150,153] 
trigger1 = command = "y"

;Combo Braker
[State -1, cb]
type = ChangeState
value = 431
triggerall = var(10)
trigger1 = statetype != A
trigger1 = stateno = [150,153] 
trigger1 = command = "cz"


; Void
[State -1]
type = null;ChangeState
value = 111
triggerall = !var(10)
triggerall = command = "holdback"
triggerall = command = "c"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [150,153]
trigger3 = stateno = 100
[State -1]
type = null;ChangeState
value = 109
triggerall = !var(10)
triggerall = command = "c"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [150,153]
trigger3 = stateno = 100

[State -1]
type = null;ChangeState
value = 112
triggerall = !var(10)
triggerall = command = "holdback"
triggerall = command = "c"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = [150,153]
trigger3 = stateno = 100
[State -1]
type = null;ChangeState
value = 110
triggerall = !var(10)
triggerall = command = "c"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = [150,153]
trigger3 = stateno = 100



; dash
[State -1]
type = ChangeState
value = 100
triggerall = var(10)
triggerall = command = "b"
triggerall = statetype != A
trigger1 = ctrl = 1
[State -1]
type = ChangeState
value = 100
triggerall = var(10)
triggerall = command = "holdback"
triggerall = command = "b"
triggerall = statetype != A
trigger1 = ctrl = 1


; dash aereo
[State -1]
type = ChangeState
value = 102
triggerall = var(10)
triggerall = command = "holdback"
triggerall = command = "b"
triggerall = statetype = A
trigger1 = ctrl = 1
[State -1]
type = ChangeState
value = 102
triggerall = var(10)
triggerall = command = "b"
triggerall = statetype = A
trigger1 = ctrl = 1



;------ Charge ------
[State -1]
type = ChangeState
value = 196
triggerall = !var(10)
triggerall = power < 4000
triggerall = command = "cz"
triggerall = stateno != [50,120]
trigger1 = statetype != A
trigger1 = ctrl


;------ Taunt ------
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;----- Agarre ------
[State -1]
type = ChangeState
value = 900
triggerall = command = "by"
triggerall = !var(10)
triggerall = (Command = "holdfwd") || (Command = "holdback")
;triggerall = (P2BodyDist X < 15) && (p2stateno != [5100,5120])
triggerall = statetype != A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = stateno = [200,650]
trigger3 = stateno = [150,153]


;===========================================================================
;                           Golpes Normales
;===========================================================================

; Dash Hit
[State -1]
type = ChangeState
value = 431
triggerall = !var(10)
triggerall = command = "cz"
triggerall = stateno = 100
trigger1 = statetype != A




; Shoryuenza 			<<<< command
[State -1]
type = ChangeState
value = 1000
triggerall = var(10)
triggerall = command = "ShoryuenzanX"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [770,777]) || (stateno = [1201,1202]) || (stateno = [410,430])
trigger2 = stateno != 775
trigger2 = MoveContact
trigger3 = stateno = 100

; MoonSlash			<<<< command
[State -1]
type = ChangeState
value = 1200
triggerall = var(10)
triggerall = command = "MoonslashX"
;triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [770,777])
trigger2 = stateno != 775
trigger2 = MoveContact
trigger3 = stateno = 100

; Golpe upper parado 		<<<< command
[State -1]
type = ChangeState
value = 775
triggerall = var(10)
triggerall = command = "UpperX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [770,777])
trigger2 = stateno != 775
trigger2 = MoveContact
trigger3 = (stateno = 700)
trigger3 = time > 24
trigger4 = stateno = 100


; Golpe slasher parado  	<<<< command
[State -1]
type = ChangeState
value = 774
triggerall = var(10)
triggerall = command = "SlasherX"
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = (stateno = [770,777])
trigger2 = prevstateno != 774
trigger2 = MoveContact
trigger3 = (stateno = 700)
trigger3 = time > 24
trigger4 = stateno = 100

[State -1]
type = ChangeState
value = 700
triggerall = var(10)
triggerall = command = "y"
triggerall = statetype != A
trigger1 = (stateno = 772)
trigger1 = MoveContact
trigger2 = ctrl = 1

[State -1]
type = ChangeState
value = 1053
triggerall = var(10)
triggerall = command = "y"
triggerall = statetype != A
trigger1 = (stateno = [773,775]) || (stateno = 420)
trigger1 = MoveContact
trigger2 = ctrl = 1





; Golpe upper parado
[State -1]
type = null;ChangeState
value = 775
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype != A
trigger1 = (stateno = 774)
trigger1 = MoveContact
trigger1 = time > 27
trigger2 = stateno = 774
trigger2 = time > 28
trigger3 = (stateno = 1201)
trigger3 = time > 10
; Golpe slasher parado
[State -1]
type = null;ChangeState
value = 774
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype != A
trigger1 = (stateno = 773)
trigger1 = MoveContact
trigger1 = time > 17
trigger2 = (stateno = 773)
trigger2 = time > 17

;Golpe fuerte parado
[State -1]
type = null;ChangeState
value = 773
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype != A
trigger1 = (stateno = 772)
trigger1 = MoveContact
trigger1 = time > 9
trigger2 = stateno = 772
trigger2 = time > 9
;Golpe medio parado
[State -1]
type = null;ChangeState
value = 772
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype != A
trigger1 = (stateno = 771) || (stateno = [410,430])
trigger1 = MoveContact
trigger1 = time >= 7
trigger2 = (stateno = 771) || (stateno = [410,430])
trigger2 = time >= 9
;Golpe debil parado
[State -1]
type = null;ChangeState
value = 771
triggerall = var(10)
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl = 1







[State -1]
type = ChangeState
value = 430
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype != A
trigger1 = (stateno = 220)
trigger1 = MoveContact
trigger1 = time > 27
trigger2 = stateno = 220
trigger2 = time > 28
trigger3 = (stateno = 220)
trigger3 = time > 10
; Golpe slasher parado
[State -1]
type = ChangeState
value = 220
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype != A
trigger1 = (stateno = 420)
trigger1 = MoveContact
trigger1 = time > 9
trigger2 = (stateno = 420)
trigger2 = time > 9
[State -1]
type = ChangeState
value = 420
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype != A
trigger1 = (stateno = 210)
trigger1 = MoveContact
trigger1 = time > 12
trigger2 = stateno = 210
trigger2 = time > 12
;Golpe medio parado
[State -1]
type = ChangeState
value = 210
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype != A
trigger1 = (stateno = 200)
trigger1 = MoveContact
trigger1 = time >= 7
trigger2 = (stateno = 200)
trigger2 = time >= 9
;Golpe debil parado
[State -1]
type = ChangeState
value = 200
triggerall = var(10)
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl = 1






;Golpe debil parado
[State -1]
type = ChangeState
value = 200
triggerall = !var(10)
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,410]
trigger2 = MoveContact
trigger2 = time >= 4

;Golpe medio parado
[State -1]
type = ChangeState
value = 210
triggerall = !var(10)
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = (MoveContact) || (time >= 9) 
trigger3 = stateno = [400,420]
trigger3 = (MoveContact) || (time >= 4) 


;Golpe fuerte parado
[State -1]
type = ChangeState
value = 220
triggerall = !var(10)
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,210]
trigger2 = (MoveContact) || (time >= 6) 
trigger3 = stateno = [400,430]
trigger3 = (MoveContact) || (time >= 4) 


;Golpe slasher agachado
[State -1]
type = ChangeState
value = 430
triggerall = !var(10)
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,220]) || (stateno = 420)
trigger2 = (MoveContact) || (time >= 11) 
trigger3 = stateno = [400,410]
trigger3 = time >= 4
trigger4 = (stateno = 200) && (time >= 8)

; Golpe slasher parado
[State -1]
type = ChangeState
value = 470
triggerall = !var(10)
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,210]) || (stateno = [400,460])
trigger2 = stateno != 410
trigger2 = stateno != 430
trigger2 = (MoveContact) || (time >= 6) 
trigger3 = (stateno = 410) || (stateno = 430) || (stateno = 220)
trigger3 = (MoveContact) || (time >= 20) 
trigger4 = stateno = 400
trigger4 = time >= 4

; Smasher
[State -1]
type = ChangeState
value = 700
triggerall = !var(10)
triggerall = command = "c"
triggerall = statetype != A
triggerall = stateno != 230
trigger1 = ctrl
trigger2 = (stateno = [200,230]) || (stateno = [400,420])
trigger2 = (MoveContact) || (time >= 9) 
trigger2 = stateno != 410
trigger3 = stateno = [150,153]
trigger4 = (stateno = [430,460]) || (stateno = 220)
trigger4 = (MoveContact) || (time >= 16) 
trigger5 = stateno = 470
trigger5 = (MoveContact) || (time >= 25) 

;===========================================================================
;                           Golpes Agachado
;===========================================================================


; Golpe debil agachado
[State -1]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = [200,210]
trigger2 = (MoveContact) || (time >= 9) 
trigger3 = stateno = 410
trigger3 = time >= 4


; Golpe medio agachado
[State -1]
type = ChangeState
value = 410
triggerall = !var(10)
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = [200,210]) || (stateno = 400) || (stateno = 420)
trigger2 = MoveContact
trigger3 = stateno = 200
trigger3 = time >= 9
trigger4 = stateno = 400
trigger4 = time >= 4

; Golpe fuerte agachado
[State -1]
type = ChangeState
value = 420
triggerall = !var(10)
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = [200,210]
trigger2 = (MoveContact) || (time >= 9) 
trigger3 = stateno = 400
trigger3 = (MoveContact) || (time >= 4) 
trigger4 = stateno = 410
trigger4 = (MoveContact) || (time >= 16) 

;Golpe slasher agachado
[State -1]
type = ChangeState
value = 430
triggerall = !var(10)
triggerall = prevstateno != 430
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = (stateno = [200,220]) || (stateno = [400,420])
trigger2 = (MoveContact) || (time >= 11) 
trigger2 = stateno != 410
trigger3 = stateno = 400
trigger3 = time >= 4
trigger4 = stateno = 430
trigger4 = (MoveContact) || (time >= 25) 
trigger5 = stateno = 410
trigger5 = (MoveContact) || (time >= 16) 
;trigger6 = stateno = 470
;trigger6 = (MoveContact) && (prevstateno != 430)

; Golpe slasher parado
[State -1]
type = ChangeState
value = 230
triggerall = !var(10)
triggerall = prevstateno != 420
triggerall = command = "z"
triggerall = command = "holddown"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,210]) || (stateno = [400,470])
trigger2 = ((MoveContact) && (time >= 9)) || (time >= 9) 
trigger2 = stateno != 410
trigger3 = (stateno = 220)
trigger3 = time > 14
trigger4 = (stateno = 431)
trigger4 = MoveContact
trigger5 = stateno = 400
trigger5 = time >= 4
trigger6 = stateno = 410
trigger4 = (MoveContact) || (time >= 16) 

;===========================================================================
;                           Golpes Saltando
;===========================================================================

;Golpe slasher Saltando <<<< command
[State -1]
type = ChangeState
value = 640
triggerall = var(10)
triggerall = command = "y"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,630])
trigger2 = MoveContact

;Golpe slasher Saltando
[State -1]
type = ChangeState
value = 640
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype = A
trigger1 = (stateno = 630)
trigger1 = (MoveContact) || (time >= 13) 
;Golpe slasher Saltando
[State -1]
type = ChangeState
value = 630
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype = A
trigger1 = (stateno = 620)
trigger1 = (MoveContact) || (time >= 13) 
;Golpe fuerte Saltando
[State -1]
type = ChangeState
value = 620
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype = A
trigger1 = (stateno = 610)
trigger1 = (MoveContact) || (time >= 9) 
;Golpe medio Saltando
[State -1]
type = ChangeState
value = 610
triggerall = var(10)
triggerall = command = "x"
triggerall = statetype = A
trigger1 = (stateno = 600)
trigger1 = (MoveContact) || (time > 9) 
;Golpe fuerte Saltando <<<< command
[State -1]
type = ChangeState
value = 620
triggerall = var(10)
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = statetype = A
trigger1 = ctrl
;Golpe debil Saltando
[State -1]
type = ChangeState
value = 610
triggerall = var(10)
triggerall = command = "x"
triggerall = vel x = 0
triggerall = command != "holddown"
triggerall = statetype = A
trigger1 = ctrl

;Golpe debil Saltando
[State -1]
type = ChangeState
value = 610
triggerall = var(10)
triggerall = command = "x"
triggerall = vel x != 0
triggerall = command != "holddown"
triggerall = statetype = A
trigger1 = ctrl



; golpe debil saltando
[State -1]
type = ChangeState
value = 600
triggerall = !var(10)
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 610)
trigger2 = ((MoveContact) && (time >= 8)) || (time >= 8) 

; golpe medio saltando
[State -1]
type = ChangeState
value = 610
triggerall = !var(10)
triggerall = (command = "a")
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600)
trigger2 = MoveContact
trigger3 = (stateno = 600)
trigger3 = time > 7


; golpe fuerte saltando
[State -1]
type = ChangeState
value = 620 
triggerall = !var(10)
triggerall = (command = "y")
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,610])
trigger2 = ((MoveContact) && (time >= 7)) || (time >= 7) 

; golpe fuerte saltando
[State -1]
type = ChangeState
value = 630
triggerall = !var(10)
triggerall = (command = "b")
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,620])
trigger2 = ((MoveContact) && (time >= 7)) || (time >= 7) 

; golpe slasher saltando
[State -1]
type = ChangeState
value = 640 
triggerall = !var(10)
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,610])
trigger2 = ((MoveContact) && (time >= 7)) || (time >= 7) 
trigger3 = (stateno = 620)
trigger3 = ((MoveContact) && (time >= 13)) || (time >= 13) 
trigger4 = (stateno = 630)
trigger4 = ((MoveContact) && (time >= 23)) || (time >= 23) 

; golpe slasher saltando
[State -1]
type = ChangeState
value = 650 
triggerall = !var(10)
triggerall = (command = "c")
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = 640) 
trigger2 = ((MoveContact) && (time >= 7)) || (time >= 7) 
trigger3 = (stateno = 620)
trigger3 = ((MoveContact) && (time >= 13)) || (time >= 13) 
trigger4 = (stateno = 630)
trigger4 = ((MoveContact) && (time >= 23)) || (time >= 23) 

;===========================================================================
;                         Alpha's Other Stuff
;===========================================================================

;--- Salto (X's) ------
[State -1]
type = ChangeState
value = 45;0
triggerall = var(10)
triggerall = var(9) < 3
triggerall = stateno != 45 
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno =100 || stateno = 105


[State -1]
type = ChangeState
value = 45;0
triggerall = var(10)
triggerall = var(9) < 3
triggerall = stateno != 45
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = ctrl


[State -1]
type = ChangeState
value = 10023;40
triggerall = var(10)
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno =100 || stateno = 105


;--- Sin agachar ------
[State -1]
type = null;ChangeState
value = 0
triggerall = !var(10)
trigger1 = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl

;--- Sin Saltar ------
[State -1]
type = ChangeState
value = 0
triggerall = var(10)
trigger1 = command = "ar"
trigger1 = statetype != A
trigger1 = ctrl

;--- Sin Saltar (caminata) ------
[State -1]
type = ChangeState
value = 20
triggerall = var(10)
trigger1 = command = "at"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = command = "ad"
trigger2 = statetype != A
trigger2 = ctrl


;recovery Roll
[State -1]
type = ChangeState
value = 680
triggerall = command = "FF"
triggerall = life >= 1
trigger1 = stateno = 5110
trigger2 = stateno = 5120
trigger2 = time  < 25


;------ Dash ------
[State -1]
type = ChangeState
value = 100
triggerall = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;------ Air Dash ------
[State -1]
type = ChangeState
value = 102
triggerall = !var(7)
triggerall = Stateno != 102
triggerall = command = "FF"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = StateNo = 050
trigger2 = time >= 7

;---------------------------------------------------------------------------
;recovery Roll
[State -1]
type = ChangeState
value = 690
triggerall = command = "BB"
triggerall = life >= 1
trigger1 = stateno = 5110 ; || stateno = 5120
trigger2 = stateno = 5120
trigger2 = time  < 25


;------ dash atras  ------
[State -1]
type = ChangeState
value = 105
triggerall = !var(7)
triggerall = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl



;---------------------------------------------------------------------------
; Superjump Up
[State -1, Superjump Up]
type = ChangeState
value = 10023
trigger1 = command = "sjump"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Superjump Fwd
[State -1, Superjump Fwd]
type = ChangeState
value = 10024
trigger1 = command = "sjumpf"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Superjump Back
[State -1, Superjump Back]
type = ChangeState
value = 10025
trigger1 = command = "sjumpb"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl


;----Air recovery------
[State -1]
type = ChangeState
value = 5210
triggerall = life >= 1
triggerall = Pos Y < -69
trigger1 = command = "recovery"
trigger1 = stateno != 5020
trigger1 = stateno != 5030
trigger1 = stateno = [5001,5170]


;--super jump counter
[State -1]
type = ChangeState
value = 2959
trigger1 = stateno = [150,153] 
trigger1 = command = "sjump"



[State -1]
type = ChangeState
value = 10027
triggerall = backEdgeBodyDist <= 0
triggerall = Pos Y <= -25
triggerall = Pos Y > -300
triggerall = ctrl
trigger1 = command = "wjumpb"
[State -1]
type = ChangeState
value = 10028
triggerall = frontEdgeBodyDist <= 0
triggerall = Pos Y <= -25
triggerall = Pos Y > -300
triggerall = ctrl
trigger1 = command = "wjumpf"


;------------------

;------------------------------------
;AI Guardia (parado) auto
;------------------------------------
[State -1]
type = ChangeState
triggerall = Statetype != A
triggerall = P2statetype != C
triggerall = Statetype = S
triggerall = P2Movetype = A
triggerall = var(7) = 1
trigger1 = p2bodydist X = [-150,150]
trigger1 = Ctrl = 1
value = 130

;------------------------------------
;AI Guardia (par-aga)
;------------------------------------
[State -1]
type = ChangeState
triggerall = StateType != A
triggerall = P2statetype = C
triggerall = P2Movetype = A
trigger1 = StateNo = 150
trigger1 = 1
value = 152

;------------------------------------
;AI Guardia (Agachado) auto
;------------------------------------
[State -1]
type = ChangeState
triggerall = StateType != A
triggerall = P2statetype = C
triggerall = P2Movetype = A
triggerall = var(7) = 1
trigger1 = p2bodydist X = [-150,140]
trigger1 = Ctrl = 1
value = 131

;------------------------------------
;AI Guardia (aga-par)
;------------------------------------
[State -1]
type = ChangeState
triggerall = Statetype != A
triggerall = P2statetype != C
triggerall = P2Movetype = A
trigger1 = 1
trigger1 = StateNo = 152
value = 150

;------------------------------------
;AI Guardia (aereo) auto
;------------------------------------
[State -1]
type = ChangeState
triggerall = Statetype = A
triggerall = P2Movetype = A
triggerall = var(7) = 1
trigger1 = p2bodydist X = [-150,140]
trigger1 = Ctrl = 1
value = 132

;------------------------------------
;AI Guardia (aer-aga)
;------------------------------------
[State -1]
type = ChangeState
triggerall = Statetype != A
triggerall = Pos Y > -1
triggerall = P2statetype = C
triggerall = P2Movetype = A
trigger1 = stateno = 154
trigger2 = stateno = 155
value = 152

;------------------------------------
;AI Guardia (aer-par)
;------------------------------------
[State -1]
type = ChangeState
triggerall = Statetype != A
triggerall = Pos Y > -1
triggerall = P2statetype != C
trigger1 = stateno = 154
trigger2 = stateno = 155
value = 150

;===========================================================================
;                        PRESENTED by ArielAleXCo.
;===========================================================================

